<?php
/*
 * Implements theme_menu_link() hook to recognize external URLs and add class "external".
 */
function rijkshuisstijl_menu_link($variables) {

  $link = &$variables['element'];

  // unset all the classes
  unset($variables['element']['#attributes']['class']);

  $element = $variables['element'];
  $sub_menu = '';

  if ($element['#below']) {
    $sub_menu = drupal_render($element['#below']);
  }

  $output = l($element['#title'], $element['#href'], $element['#localized_options']);
  return '<li' . drupal_attributes($element['#attributes']) . '>' . $output . $sub_menu . "</li>\n";
}

function rijkshuisstijl_menu_link__menu_block($variables) {
  $attributes = $variables['element']['#attributes'];

  $element = $variables['element'];
  $element['#attributes']['class'] = array();

  if(in_array('first', $attributes['class'])) {
    $element['#attributes']['class'][] = 'first-item';
  }

  if(in_array('active', $attributes['class'])) {
    $element['#attributes']['class'][] = 'active';
  }

  $sub_menu = '';
  if ($element['#below']) {
    $sub_menu = drupal_render($element['#below']);
    $element['#attributes']['class'][] = 'open';
  }
  elseif ($element['#below'] == false && in_array('active-trail', $attributes['class'])) {
    $element['#attributes']['class'][] = 'active';
  }

  $output = l($element['#title'], $element['#href'], array_merge($element['#localized_options'], array('html' => TRUE)));
  return '<li' . drupal_attributes($element['#attributes']) . '>' . $output . $sub_menu . "</li>\n";
}

/**
 * Implements theme_links().
 */
function rijkshuisstijl_links__system_main_menu($variables) {
  $links = $variables['links'];
  $attributes = $variables['attributes'];
  $heading = $variables['heading'];
  global $language_url;
  $output = '';

  if (count($links) > 0) {
    $output = '';

    // Treat the heading first if it is present to prepend it to the
    // list of links.
    if (!empty($heading)) {
      if (is_string($heading)) {
        // Prepare the array that will be used when the passed heading
        // is a string.
        $heading = array(
          'text' => $heading,
          // Set the default level of the heading. 
          'level' => 'h2',
        );
      }

      $output .= '<' . $heading['level'];
      if (!empty($heading['class'])) {
        $output .= drupal_attributes(array('class' => $heading['class']));
      }

      $output .= '>' . check_plain($heading['text']) . '</' . $heading['level'] . '>';
    }

    $output .= '<ul' . drupal_attributes($attributes) . '>';

    $num_links = count($links);
    $i = 1;

    foreach ($links as $key => $link) {
      $class = array($key);

      // Add first, last and active classes to the list of links to help out themers.
      if ($i == 1) {
        $class[] = 'first-item';
      }

      if ($i == $num_links) {
        $class[] = 'last-item';
      }
  
      if (isset($link['href']) && ($link['href'] == $_GET['q'] || ($link['href'] == '<front>' && drupal_is_front_page())) && (empty($link['language']) || $link['language']->language == $language_url->language)) {
          $class[] = 'sel';
      }

      if(strstr($key, 'active-trail') !== false && !in_array('sel', $class)) {
        $class[] = 'sel';
      }
  
      $output .= '<li' . drupal_attributes(array('class' => $class)) . '>';

      if (isset($link['href']) && !empty($link['title'])) {
        // Pass in $link as $options, they share the same keys.
        $output .= l($link['title'], $link['href'], array_merge($link, array('html' => TRUE)));
      }
      elseif (!empty($link['title'])) {
        // Some links are actually not links, but we wrap these in <span> for adding title and class attributes.
        if (empty($link['html'])) {
          $link['title'] = check_plain($link['title']);
        }

        $span_attributes = '';
        if (isset($link['attributes'])) {
          $span_attributes = drupal_attributes($link['attributes']);
        }

        $output .= '<span' . $span_attributes . '>' . $link['title'] . '</span>';
      }

      $i++;
      $output .= "</li>\n";
    }

    $output .= '</ul>';
  }

  return $output;
}

function rijkshuisstijl_menu_local_tasks(&$variables) {
  $output = '';

  if (!empty($variables['primary'])) {
    //$variables['primary']['#prefix'] = '<h2 class="element-invisible">' . t('Primary tabs') . '</h2>';
    $variables['primary']['#prefix'] = '<ul class="tabs primary">';
    $variables['primary']['#suffix'] = '</ul>';
    $output .= drupal_render($variables['primary']);
  }
  
  if (!empty($variables['secondary'])) {
    //$variables['secondary']['#prefix'] = '<h2 class="element-invisible">' . t('Secondary tabs') . '</h2>';
    $variables['secondary']['#prefix'] = '<ul class="tabs secondary">';
    $variables['secondary']['#suffix'] = '</ul>';
    $output .= drupal_render($variables['secondary']);
  }

  if(strlen($output) > 0) {
    $output = '<div class="tabs">' . $output . '</div>';
  }

  return $output;
}