<?php
/**
 * Implements theme_pager().
 * 
 * Removed h2, first and last link
 */
function rijkshuisstijl_pager($variables) {
    $tags = $variables['tags'];
    $element = $variables['element'];
    $parameters = $variables['parameters'];
    $quantity = $variables['quantity'];
    global $pager_page_array, $pager_total;

    // Calculate various markers within this pager piece:
    // Middle is used to "center" pages around the current page.
    $pager_middle = ceil($quantity / 2);
    // current is the page we are currently paged to
    $pager_current = $pager_page_array[$element] + 1;
    // first is the first page listed by this pager piece (re quantity)
    $pager_first = $pager_current - $pager_middle + 1;
    // last is the last page listed by this pager piece (re quantity)
    $pager_last = $pager_current + $quantity - $pager_middle;
    // max is the maximum page number
    $pager_max = $pager_total[$element];
    // End of marker calculations.

    // Prepare for generation loop.
    $i = $pager_first;
    if ($pager_last > $pager_max) {
        // Adjust "center" if at end of query.
        $i = $i + ($pager_max - $pager_last);
        $pager_last = $pager_max;
    }
    
    if ($i <= 0) {
        // Adjust "center" if at start of query.
        $pager_last = $pager_last + (1 - $i);
        $i = 1;
    }
    // End of generation loop preparation.

    $previous = theme('pager_previous', array('text' => (isset($tags[1]) ? $tags[1] : t('Previous')), 'element' => $element, 'interval' => 1, 'parameters' => $parameters, 'attributes' => array('class' => array('prev'))));
    $next = theme('pager_next', array('text' => (isset($tags[3]) ? $tags[3] : t('Next')), 'element' => $element, 'interval' => 1, 'parameters' => $parameters, 'attributes' => array('class' => array('next'))));

    $output = "<div class='nav_page'>";
    if ($pager_total[$element] > 1) {
        if ($previous) {
            $output .= $previous . " | ";
        }

        if ($i != $pager_max) {
            if ($i > 1) {
                // Three dot ellipsis.
                $output .= "&#8230; | ";
            }

            // Now generate the actual pager piece.
            for (; $i <= $pager_last && $i <= $pager_max; $i++) {
                if ($i < $pager_current) {
                    $output .= theme('pager_previous', array('text' => $i, 'element' => $element, 'interval' => ($pager_current - $i), 'parameters' => $parameters)) . " | ";
                }

                if ($i == $pager_current) {
                    $output .= "<span class='current'>" . $i . "</span> | ";
                }

                if ($i > $pager_current) {
                    $output .= theme('pager_next', array('text' => $i, 'element' => $element, 'interval' => ($i - $pager_current), 'parameters' => $parameters)) . " | ";
                }
            }

            if ($i < $pager_max) {
                // Three dot ellipsis.
                $output .= "&#8230; | ";
            }
        }

        if ($next) {
            $output .= $next;
        }
    }

    $output .=  "</div>";
    return $output;
}

/**
 * Implements theme_pager_first().
 */
function rijkshuisstijl_pager_first($variables) {
    $text = $variables['text'];
    $element = $variables['element'];
    $parameters = $variables['parameters'];
    $attributes = isset($variables['attributes']) ? $variables['attributes'] : array();
    global $pager_page_array;
    $output = '';

    // If we are anywhere but the first page
    if ($pager_page_array[$element] > 0) {
        $output = theme('pager_link', array('text' => $text, 'page_new' => pager_load_array(0, $element, $pager_page_array), 'element' => $element, 'parameters' => $parameters, 'attributes' => $attributes));
    }

    return $output;
}

/**
 * Implements theme_pager_last().
 */
function rijkshuisstijl_pager_last($variables) {
    $text = $variables['text'];
    $element = $variables['element'];
    $parameters = $variables['parameters'];
    $attributes = isset($variables['attributes']) ? $variables['attributes'] : array();
    global $pager_page_array, $pager_total;
    $output = '';

    // If we are anywhere but the last page
    if ($pager_page_array[$element] < ($pager_total[$element] - 1)) {
        $output = theme('pager_link', array('text' => $text, 'page_new' => pager_load_array($pager_total[$element] - 1, $element, $pager_page_array), 'element' => $element, 'parameters' => $parameters, 'attributes' => $attributes));
    }

    return $output;
}

/**
 * Implements theme_pager_next().
 */
function rijkshuisstijl_pager_next($variables) {
    $text = $variables['text'];
    $element = $variables['element'];
    $interval = $variables['interval'];
    $parameters = $variables['parameters'];
    $attributes = isset($variables['attributes']) ? $variables['attributes'] : array();
    global $pager_page_array, $pager_total;
    $output = '';

    // If we are anywhere but the last page
    if ($pager_page_array[$element] < ($pager_total[$element] - 1)) {
        $page_new = pager_load_array($pager_page_array[$element] + $interval, $element, $pager_page_array);
        // If the next page is the last page, mark the link as such.
        if ($page_new[$element] == ($pager_total[$element] - 1)) {
            $output = theme('pager_last', array('text' => $text, 'element' => $element, 'parameters' => $parameters, 'attributes' => $attributes));
        }
        // The next page is not the last page.
        else {
            $output = theme('pager_link', array('text' => $text, 'page_new' => $page_new, 'element' => $element, 'parameters' => $parameters, 'attributes' => $attributes));
        }
    }
    
    return $output;
}

/**
 * Implements theme_pager_previous().
 */
function rijkshuisstijl_pager_previous($variables) {
    $text = $variables['text'];
    $element = $variables['element'];
    $interval = $variables['interval'];
    $parameters = $variables['parameters'];
    $attributes = isset($variables['attributes']) ? $variables['attributes'] : array();
    global $pager_page_array;
    $output = '';

    // If we are anywhere but the first page
    if ($pager_page_array[$element] > 0) {
        $page_new = pager_load_array($pager_page_array[$element] - $interval, $element, $pager_page_array);

        // If the previous page is the first page, mark the link as such.
        if ($page_new[$element] == 0) {
            $output = theme('pager_first', array('text' => $text, 'element' => $element, 'parameters' => $parameters, 'attributes' => $attributes));
        }
        // The previous page is not the first page.
        else {
            $output = theme('pager_link', array('text' => $text, 'page_new' => $page_new, 'element' => $element, 'parameters' => $parameters, 'attributes' => $attributes));
        }
    }
    
    return $output;
}