<?php
/**
 * Implements hook_css_alter().
 *
 * Remove Drupal's core system stylesheets.
 * They aren't compatible with the Rijkshuisstijl starterskit library.
 */
function rijkshuisstijl_css_alter(&$css) {
  $path_system = drupal_get_path('module', 'system');

  // Remove system stylesheets.
  $remove = array(
      $path_system . '/system.base.css',
      $path_system . '/system.menus.css',
      $path_system . '/system.messages.css',
      $path_system . '/system.theme.css',
  );

  // Remove module-specific stylesheets.
  $remove[] = drupal_get_path('module', 'webform') . '/css/webform.css';

  // Remove stylesheets which match our remove array.
  foreach ($css as $stylesheet => $options) {
      if (in_array($stylesheet, $remove)) {
          unset($css[$stylesheet]);
      }
  }
}

/**
 * This functions includes all the starterkit library stylesheets.
 */
function rijkshuisstijl_add_stylesheets(&$variables) {
  // Load the starterskit from the libraries api.
  if (!($library = libraries_load('starterskit')) || empty($library['loaded'])) {
      // TODO: Give an error if the starterskit can't be loaded.
  }
    
  // Add conditional stylesheets for IE.
  drupal_add_css(path_to_theme() . '/styles/ie/ie.css',
    array(
      'group' => CSS_THEME,
      'browsers' => array(
        'IE' => TRUE,
        '!IE' => FALSE,
      ),
      'preprocess' => FALSE,
      'every_page' => TRUE,
      'media' => 'screen',
    )
  );
  drupal_add_css(path_to_theme() . '/styles/ie/ie-7.css',
    array(
      'group' => CSS_THEME,
      'browsers' => array(
        'IE' => 'IE 7',
        '!IE' => FALSE,
      ),
      'preprocess' => FALSE,
      'every_page' => TRUE,
      'media' => 'screen',
    )
  );
  drupal_add_css(path_to_theme() . '/styles/ie/ie-8.css',
    array(
      'group' => CSS_THEME,
      'browsers' => array(
        'IE' => 'IE 8',
        '!IE' => FALSE,
      ),
      'preprocess' => FALSE,
      'every_page' => TRUE,
      'media' => 'screen',
    )
  );      
}