<?php
require_once dirname(__FILE__) . '/includes/form.inc';
require_once dirname(__FILE__) . '/includes/webform.inc';
require_once dirname(__FILE__) . '/includes/menu.inc';
require_once dirname(__FILE__) . '/includes/pager.inc';
require_once dirname(__FILE__) . '/includes/stylesheets.inc';

/**
 * Implements theme_breadcrumb().
 *
 * Replaced › character by > character.
 */
function rijkshuisstijl_breadcrumb($variables) {
    $breadcrumb = $variables['breadcrumb'];

    if (!empty($breadcrumb)) {
        $title = drupal_get_title();
    
        if (!empty($title)) {
            $breadcrumb[] = $title;
      
            if (strip_tags($breadcrumb[(sizeof($breadcrumb)-2)]) == $breadcrumb[sizeof($breadcrumb)-1]) {
                unset($breadcrumb[(sizeof($breadcrumb)-2)]);
            }
        }

        return '<div class="breadcrumb"><p><em>' . t('You are here') . ': </em>'. implode('<span class="imgreplacement"> &#8250; </span>', $breadcrumb) .'</p></div>';    
    }
}

/**
 * Implements hook_item_list().
 *
 * Removed wrapping <div>
 * Rename .first and .last class from item-list by default
 */
function rijkshuisstijl_item_list($variables) {
    $items = $variables['items'];
    $title = $variables['title'];
    $type = $variables['type'];
    $attributes = $variables['attributes'];

    $output = '';
    //$output = '<div class="item-list">';
    if (isset($title)) {
        $output .= '<h3>' . $title . '</h3>';
    }

    if (!empty($items)) {
        $output .= "<$type" . drupal_attributes($attributes) . '>';
        $num_items = count($items);
        foreach ($items as $i => $item) {
            $attributes = array();
            $children = array();
            $data = '';

            if (is_array($item)) {
                foreach ($item as $key => $value) {
                    if ($key == 'data') {
                        $data = $value;
                    }
                    elseif ($key == 'children') {
                        $children = $value;
                    }
                    else {
                        $attributes[$key] = $value;
                    }
                }
            }
            else {
                $data = $item;
            }

            if (count($children) > 0) {
                // Render nested list.
                $data .= theme_item_list(array('items' => $children, 'title' => NULL, 'type' => $type, 'attributes' => $attributes));
            }

            if ($i == 0) {
                $attributes['class'][] = 'first-item';
            }

            if ($i == $num_items - 1) {
                $attributes['class'][] = 'last-item';
            }

            $output .= '<li' . drupal_attributes($attributes) . '>' . $data . "</li>\n";
        }
        
        $output .= "</$type>";
    }

    $output .= '';
    //$output .= '</div>';
    return $output;
}

/**
 * Implements theme_link().
 * Override links to add an 'external' class if needed.
 *
 * Only adds the external class to external links that
 * don't contain an image.
 */
function rijkshuisstijl_link($variables) {
  global $base_url;
  if (
    // Is the URL absolute?
    url_is_external($variables['path']) &&
    // The site url is not part of the path.
    strstr($variables['path'], $base_url) === FALSE &&
    // The link does not contain an image (to prevent double images).
    strstr($variables['text'], '<img ') === FALSE
  ) {
    $variables['options']['attributes']['class'][] = 'external';
    $variables['options']['html'] = TRUE;

    if (isset($variables['options']['attributes']['title'])) {
      $title = &$variables['options']['attributes']['title'];
      $title = t('External site: @title', array('@title' => $title));
    }
    else {
      $variables['options']['attributes']['title'] = t('External site');
    }
  }
  return '<a href="' . check_plain(url($variables['path'], $variables['options'])) . '"' . drupal_attributes($variables['options']['attributes']) . '>' . ($variables['options']['html'] ? $variables['text'] : check_plain($variables['text'])) . '</a>';
}

/**
 * Implements hook_preprocess().
 */
function rijkshuisstijl_preprocess(&$variables, $hook) {
    if (!($library = libraries_load('starterskit')) || empty($library['loaded'])) {
        // TODO: Give an error if the starterskit can't be loaded.
    }
    else {
        $variables['starterskit'] = $library;
    }

    $variables['rdf_enabled'] = module_exists('rdf') ? 1 : 0;
}

/**
 * Implements hook_preprocess_html().
 */
function rijkshuisstijl_preprocess_html(&$variables) {
    // Append the system_type class to the body classes.
    $variables['classes_array'][] = theme_get_setting('system_type');

    if ($variables['is_front']) {
        $pageID = 'home';
    }
    else if (current_path() == 'user/login' || current_path() == 'user/password') {
        $pageID = 'login';
    }
    else {
        $pageID = 'content';
    }

    $variables['attributes_array']['id'] = $pageID;

    rijkshuisstijl_add_stylesheets($variables);
  
    // Create menu 
    $menus = array(
        'menu-service-menu-right' => array(
            'menu_name'   => 'menu-service-menu-right', //: The unique name of the custom menu (composed of lowercase letters, numbers, and hyphens).
            'title'     => 'Service menu right', //: The human readable menu title.
            'description' => 'Service menu appears in the upper right corner of the page.' //:menu_save($menu)
        ),
        'menu-footer-menu-right' => array(
            'menu_name'   => 'menu-footer-menu-right', //: The unique name of the custom menu (composed of lowercase letters, numbers, and hyphens).
            'title'     => 'Footer menu right', //: The human readable menu title.
            'description' => 'Footer menu appears in the lower right corner of the page.' //:menu_save($menu)
        ),
        'menu-search-menu' => array(
            'menu_name'   => 'menu-search-menu', //: The unique name of the custom menu (composed of lowercase letters, numbers, and hyphens).
            'title'     => 'Search menu', //: The human readable menu title.
            'description' => 'Search menu appears beneath the search box.' //:menu_save($menu)
        ),      
    );

    foreach ($menus as $menu_name => $menu_data) {
        //checks if menu already exists
        if (!menu_load($menu_name)){  
            //create service menu left
            menu_save($menu_data);
        }
    }
}

/**
 * Implements hook_preprocess_page().
 */
function rijkshuisstijl_preprocess_page(&$variables) {
    $variables['classes_array'][] = theme_get_setting('color_swatch');
    $variables['classes_array'][] = theme_get_setting('system_width');

    if ($variables['is_front'] && (theme_get_setting( 'title_bar_site_title' ) == 1)){
        $variables['title_bar_name_element'] = 'h1';
        $variables['site_name_element'] = 'div';
    }
    else if ($variables['is_front'] && (theme_get_setting( 'title_bar_site_title' ) == 0)){
        $variables['title_bar_name_element'] = 'div';
        $variables['site_name_element'] = 'h1';
    }
    else{
        $variables['title_bar_name_element'] = 'div';
        $variables['site_name_element'] = 'div';
    }
}

/**
 * Implements hook_preprocess_page__user__login().
 */
function rijkshuisstijl_preprocess_page__user__login(&$variables) {
    $variables['classes_array'][] = theme_get_setting('color_swatch');
}

/**
 * Implements hook_preprocess_search_result().
 * 
 * Adding type as meta data in search results
 */
function rijkshuisstijl_preprocess_search_result(&$variables) {
    global $language;

    $result = $variables['result'];
    $variables['url'] = check_url($result['link']);
    $variables['title'] = check_plain($result['title']);
    if (isset($result['language']) && $result['language'] != $language->language && $result['language'] != LANGUAGE_NONE) {
        $variables['title_attributes_array']['xml:lang'] = $result['language'];
        $variables['content_attributes_array']['xml:lang'] = $result['language'];
    }

    $info = array();
    if (!empty($result['module'])) {
        $info['module'] = check_plain($result['module']);
    }

    if (!empty($result['type'])) {
        $info['type'] = check_plain($result['type']);
    }

    if (!empty($result['user'])) {
        $info['user'] = $result['user'];
    }

    if (!empty($result['date'])) {
        $info['date'] = format_date($result['date'], 'custom', 'j F Y');
    }

    if (isset($result['extra']) && is_array($result['extra'])) {
        $info = array_merge($info, $result['extra']);
    }

    // Check for existence. User search does not include snippets.
    $variables['snippet'] = isset($result['snippet']) ? $result['snippet'] : '';
    // Provide separated and grouped meta information..
    $variables['info_split'] = $info;
    $variables['info'] = implode(' - ', $info);
    $variables['theme_hook_suggestions'][] = 'search_result__' . $variables['module'];
}

/**
 * Implements hook_preprocess_search_results().
 *
 * Adding a search count above the search results
 */
function rijkshuisstijl_preprocess_search_results(&$variables) {
    // Extract keys as remainder of path
    // Note: support old GET format of searches for existing links.
    $path = explode('/', $_GET['q'], 3);
    $keys = empty($_REQUEST['keys']) ? '' : $_REQUEST['keys'];
    $keys = count($path) == 3 ? $path[2] : $keys;

    if (isset($GLOBALS['pager_total_items'])) { 
        // define the number of results being shown on a page
        $itemsPerPage = 10;
        $currentPage = 1;

        // get the current page
        if (isset($_REQUEST['page'])) {
            $currentPage = $_REQUEST['page'] + 1;
        }

        // get the total number of results from the $GLOBALS
        $total = $GLOBALS['pager_total_items'][0];

        // perform calculation
        $start = 10*$currentPage-9;
        $end = $itemsPerPage * $currentPage;
        if ($end>$total) $end = $total;

        // set this html to the $variables
        $variables['rijkshuisstijl_search_totals'] = t('<p><strong>@total results for ‘<em>@keys</em>’…</strong>', array('@start' => $start, '@end' => $end, '@total' => $total, '@keys' => $keys));
    }
    else {
        $variables['rijkshuisstijl_search_totals'] = '';
    }
}

/**
 * Implements theme_status_messages().
 *
 * Replace classes for messages.
 */
function rijkshuisstijl_status_messages($variables) {
    $display = $variables['display'];
    $output = '';
    $status_heading = array(
        'status'  => t('Status message'), 
        'error'   => t('Error message'), 
        'warning'   => t('Warning message'),
    );

    foreach (drupal_get_messages($display) as $type => $messages) {
        if ($type == 'error') {
            $typeextra = 'message_err';
        }
        else if ($type == 'warning'){
            $typeextra = 'message_info';
        }
        else {
            $typeextra = $type;
        }

        // Check if theme setting 'System type' is set to 'internet' which always has a sidebar right.
        if (theme_get_setting('system_type') == 'internet') {
            $output .= "<div class=\"$typeextra\">\n";
        }
        else {
            $output .= "<div class=\"mod $typeextra\">\n";
        }

        if (!empty($status_heading[$type])) {
            $output .= '<h2>' . $status_heading[$type] . "</h2>\n";
        }

        if (count($messages) > 1) {
            $output .= " <ul>\n";
    
            foreach ($messages as $message) {
                $output .= '  <li><p>' . $message . "</p></li>\n";
            }

            $output .= " </ul>\n";
        }
        else {
            $output .= '<p>'.$messages[0].'</p>';
        }

        $output .= "</div>\n";
    }

    return $output;
}

function rijkshuisstijl_file_icon($variables) {
    // Removing default Drupal file-icon image
    return '';
}

function rijkshuisstijl_file_link($variables) {
    // Removing redundant <span class="file"> tag
    $file = $variables['file'];
    $icon_directory = $variables['icon_directory'];

    $url = file_create_url($file->uri);
    $icon = theme('file_icon', array('file' => $file, 'icon_directory' => $icon_directory));

    // Set options as per anchor format described at
    // http://microformats.org/wiki/file-format-examples
    $options = array(
        'attributes' => array(
            'type' => $file->filemime . '; length=' . $file->filesize,
        ),
    );

    // Use the description as the link text if available.
    if (empty($file->description)) {
        $link_text = $file->filename;
    }
    else {
        $link_text = $file->description;
        $options['attributes']['title'] = check_plain($file->filename);
    }

    return $icon . ' ' . l($link_text, $url, $options);
}