<?php
// Include the definition of zen_theme_get_default_settings().
// include_once './' . drupal_get_path('theme', 'rijkshuisstijl') . '/template.theme-registry.inc';

function rijkshuisstijl_form_system_theme_settings_alter(&$form, $form_state)
{
    // define some vars
    $swatches = define_colors();
    $logos = define_logos();
  // add some stylesheets for the theme settings
  drupal_add_css(drupal_get_path('theme', 'rijkshuisstijl').'/styles/themesettings.css', array('group' => CSS_THEME, 'weight' => 115, 'preprocess' => FALSE));
  
  // THE theme settings
  $form['theme_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Dutch Government Style Settings'),
    '#weight' => 0,
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  );
  $form['theme_settings']['branding'] = array(
    '#type' => 'fieldset',
    '#title' => t('System Branding'),
    '#weight' => 2,
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  );
  $form['theme_settings']['internet_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Internet Settings'),
    '#weight' => 5,
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  );
  $form['theme_settings']['system_type'] = array(
  '#type' => 'radios',
  '#title' => 'System type',
  '#default_value' => theme_get_setting('system_type'),
  '#options' => array(  
    'internet' => 'Internet', 
    'intranet' => 'Intranet / External Application',
    'application' => 'Internal Application'  
    ),
  '#description' => t('The choice of <em>system</em> influenced the layout, the available colors and other theme settings.')
  );
  $form['theme_settings']['branding']['title_bar_site_title'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use Site title and Site Slogan as Title Bar'),
    '#default_value' => theme_get_setting( 'title_bar_site_title'),
    '#required' => FALSE,
    '#description' => t('When enabled, the site title and slogan will replace the content in Title Bar.')
  );
  $form['theme_settings']['branding']['title_bar'] = array(
    '#type' => 'textfield',
    '#title' => t('Title Bar'),
    '#default_value' => theme_get_setting( 'title_bar'),
    '#size' => 60,
    '#maxlength' => 128,
    '#required' => FALSE,
    '#description' => t('Contents of the title bar that appears above the menu bar.')
  );

  $form['theme_settings']['branding']['pay_off'] = array(
    '#type' => 'textfield',
    '#title' => t('Pay-off'),
    '#default_value' => theme_get_setting( 'pay_off'),
    '#size' => 60,
    '#maxlength' => 128,
    '#required' => FALSE,
    '#description' => t('Possible pay-off')
  );  

  $form['theme_settings']['branding']['color_swatch'] = array(
  '#type'           => 'radios',
  '#title'          => t('Color swatches'),
  '#options'        => $swatches,
  '#default_value'    => theme_get_setting('color_swatch'),
  '#post_render'      => array('rijkshuisstijl_radios_color_swatch')
  );

  $form['theme_settings']['branding']['system_logo'] = array(
  '#type'           => 'select',
  '#title'          => t('System Logo'),
  '#options'        => $logos,
  '#default_value'    => theme_get_setting('system_logo'),
  '#description' => t('Select the abbreviation of the government agency for a properly <em>logo</em> at the top of the page.'),
  '#weight' => '-50'
  );
  
  $form['theme_settings']['internet_settings']['system_width'] = array(
  '#type' => 'radios',
  '#title' => t('Width and column behaviour'),
  '#default_value' => theme_get_setting('system_width'),
  '#options' => array(
    'default' => 'default', 
    'wide' => 'wide',
    'wider' => 'wider',
    'liquid' => 'liquid'
    ),
  '#description' => 'Klik aan om pagina s de volledige breedte te laten innemen' 
  );

}

// alter the theme settings form for color swatches
function rijkshuisstijl_radios_color_swatch($element, $settings)
{
  global $color;
  $output = '<fieldset class="form-item form-type-radios form-item-colorswatches" id="edit-color-swatch">
    <legend for="edit-color-swatch">'.$settings['#title'].'</legend>
    <ol class="form-item form-radios">';
  
  foreach($settings['#options'] as $index => $color) {
    $selected = $index == $settings['#default_value'] ? true : false;
    $checked = $selected ? 'checked="checked"' : '';
    $checkedclass = $selected ? 'active' : '';
    //$output .= $index;
    $output .= '<li class="form-item '.$checkedclass.'">';
    $output .= '<label for="color-swatch-'.$index.'" class="option '.$index.'" title="'.$index.'">'.$index.'</label>';
    $output .= '<input type="radio" class="form-radio" value="'.$index.'" name="color_swatch" id="color-swatch-'.$index.'" '.$checked.' />';
    $output .= '</li>';
  }
  $output .= '</ol></fieldset>';
  return $output;
}

function define_colors()
{
    return array (
    'violet'    => 'violet',
    'pink'      => 'pink',  
    'red'     => 'red',
    'ruby'      => 'ruby',
    'purple'    => 'purple',
    'orange'    => 'orange',  
    'moss_green'  => 'moss_green',
    'mint_green'  => 'mint_green',
    'light_blue'  => 'light_blue',
    'azure'     => 'azure',
    'green'     => 'green',
    'yellow'    => 'yellow',
    'dark_green'  => 'dark_green',
    'dark_yellow' => 'dark_yellow',
    'dark_brown'  => 'dark_brown',
    'brown'     => 'brown',
    'intra_app'   => 'intra_app',
    );
}


function define_logos()
{
  if (module_exists('libraries')) {
    $variables['sk_library_path'] = module_invoke('libraries', 'get_path', 'starterskit') .'/';
  }
  else {
    $variables['sk_library_path'] = 'sites/all/libraries/starterskit/';
  }
  $path = './'.$variables['sk_library_path'].'/logos';
  
    $filesdir = file_scan_directory($path, '/\.png$/', array('nomask' =>'/RO_Footer_Homepage/','key' => 'name'));

    $search_replacements = array(
      'AZ_'   => 'Algemene Zaken - ',
      'BZK_'  => 'Binnenlandse Zaken en Koninkrijksrelaties - ',
      'BuZa_' => 'Buitenlandse Zaken - ',
      'ELI_'  => 'Economische Zaken, Landbouw en Innovatie - ',
      'D_'  => 'Defensie - ',
      'F_'  => 'Financiën - ',
      'IM_' => 'Infrastructuur en Milieu - ',
      'OCW_'  => 'Onderwijs, Cultuur en Wetenschap - ', 
      'SZW_'  => 'Sociale Zaken en Werkgelegenheid - ',
      'VJ_' => 'Veiligheid en Justitie - ',
      'VWS_'  => 'Volksgezondheid, Welzijn en Sport - ',
      'J_'  => 'Justitie - ',
      'WWI_'  => 'Wonen, Wijken en Integratie - ',
      'JG_' => 'Jeugd en Gezin - '
  );

  $search = array("RO_","_Logo_Homepage");
  $replacements = array("","");

  $logofiles = array();
    foreach($filesdir as $key => $value) {
    $newindex = str_replace($search, $replacements, $key);
    $logofiles[$value->filename] = str_replace(array_keys($search_replacements), array_values($search_replacements), $newindex);
    }
    
    return $logofiles;
}




